@@ -21,6 +21,8 @@
 #'   )
 #'   q$push(title = "Send back", message = "the sum.")
 #'   # See your queued messages.
+#'   # The `time` is the POSIXct `Sys.time()` stamp
+#'   # of when the message was pushed.
 #'   q$list()
 #'   q$count() # Number of messages in the queue.
 #'   q$total() # Number of messages that were ever queued.
@@ -133,6 +135,7 @@ R6_txtq <- R6::R6Class(
       out <- data.frame(
         title = base64url::base64_urlencode(as.character(title)),
         message = base64url::base64_urlencode(as.character(message)),
+        time = base64url::base64_urlencode(as.character(Sys.time())),
         stringsAsFactors = FALSE
       )
       new_total <- private$txtq_get_total() + nrow(out)
@@ -160,13 +163,7 @@ R6_txtq <- R6::R6Class(
     },
     txtq_log = function(){
       if (length(scan(private$db_file, quiet = TRUE, what = character())) < 1){
-        return(
-          data.frame(
-            title = character(0),
-            message = character(0),
-            stringsAsFactors = FALSE
-          )
-        )
+        return(null_log)
       }
       private$parse_db(
         read.table(
@@ -181,13 +178,7 @@ R6_txtq <- R6::R6Class(
     },
     txtq_list = function(n){
       if (private$txtq_count() < 1){
-        return(
-          data.frame(
-            title = character(0),
-            message = character(0),
-            stringsAsFactors = FALSE
-          )
-        )
+        return(null_log)
       }
       private$parse_db(
         read.table(
@@ -203,9 +194,10 @@ R6_txtq <- R6::R6Class(
       )
     },
     parse_db = function(x){
-      colnames(x) <- c("title", "message")
+      colnames(x) <- c("title", "message", "time")
       x$title <- base64url::base64_urldecode(x$title)
       x$message <- base64url::base64_urldecode(x$message)
+      x$time <- as.POSIXct(base64url::base64_urldecode(x$time))
       x
     }
   ),
@@ -249,3 +241,10 @@ R6_txtq <- R6::R6Class(
     }
   )
 )
+
+null_log <- data.frame(
+  title = character(0),
+  message = character(0),
+  time = as.POSIXct(character(0)),
+  stringsAsFactors = FALSE
+)
